@@ -1,8 +1,13 @@
 """A Python Wrapper to communicate with RenoWeb API."""
 
-from pyrenoweb.client import RenoeWeb
+from pyrenoweb.client import RenoWeb
 from pyrenoweb.errors import (
     InvalidApiKey,
     RequestError,
     ResultError,
 )
+from pyrenoweb.const import (
+    TYPE_METAL_GLASS,
+    TYPE_PAPER,
+    TYPE_RESIDUAL,
+)
